[gnome-shell] workspaceThumbnails: Reduce maximum thumbnail size



commit 56c28fbb039b0380677972b1ff1b0694f1f991a0
Author: Florian Müllner <fmuellner gnome org>
Date:   Thu Jun 1 15:49:46 2017 +0200

    workspaceThumbnails: Reduce maximum thumbnail size
    
    The overview's window picker is primarily about windows, and as the
    previews that represent them are more effective the bigger they are,
    it makes sense to scale down competing elements; start by reducing
    the size of workspace thumbnails on the right ...
    
    https://bugzilla.gnome.org/show_bug.cgi?id=783953

 js/ui/workspaceThumbnail.js |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/js/ui/workspaceThumbnail.js b/js/ui/workspaceThumbnail.js
index 814885a..73a6088 100644
--- a/js/ui/workspaceThumbnail.js
+++ b/js/ui/workspaceThumbnail.js
@@ -18,8 +18,8 @@ const WindowManager = imports.ui.windowManager;
 const Workspace = imports.ui.workspace;
 const WorkspacesView = imports.ui.workspacesView;
 
-// The maximum size of a thumbnail is 1/8 the width and height of the screen
-let MAX_THUMBNAIL_SCALE = 1/8.;
+// The maximum size of a thumbnail is 1/10 the width and height of the screen
+let MAX_THUMBNAIL_SCALE = 1/10.;
 
 var RESCALE_ANIMATION_TIME = 0.2;
 var SLIDE_ANIMATION_TIME = 0.2;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]